use crate::{
    config::UserConfig,
    linux::{arch_chroot, install_file},
    print_status,
};

/// Setup the users of the system
pub fn setup_users(conf: &[UserConfig]) {
    let mut doas_conf = String::new();

    for user in conf {
        arch_chroot(&["useradd", "-m", &user.name], None, false);

        arch_chroot(
            &["passwd", &user.name],
            Some(&format!("{}\n{}\n", user.password, user.password)),
            false,
        );

        if user.doas_root {
            print_status(&format!("Allowing root doas for {}", user.name));
            doas_conf.push_str(&format!("permit {} as root\n", user.name));
        }
    }

    install_file("/mnt/etc/doas.conf", &doas_conf, 0o644);
}
